@@ -74,7 +74,7 @@ def server_redis(card='eth0', size=None, newer='remi'):
 
     yum_install('redis', newer='remi')
 
-    run('chown redis.redis /storage/redis')
+    run('chown redis /storage/redis')
     run('chkconfig --level 35 redis on')
 
     ip = cmd_ip(card)
@@ -505,10 +505,12 @@ def server_phpd(user='webuser'):
     yum_install('php', newer='remi')
     yum_install('php-fpm', newer='remi')
     yum_install('php-redis', newer='remi')
+    yum_install('php-mysql', newer='remi')
     yum_install('php-pecl-yaf', newer='remi')
     yum_install('php-pecl-mongo', newer='remi')
     yum_install('php-pecl-zendopcache', newer='remi')
 
+
     run('chkconfig --level 35 php-fpm on')
     pass
 
